@@ -182,7 +182,7 @@ class WW:
 
 
     def SetSignal(self, signame, data, indices=None):
-        """Stores 'data'-array of a given Signal named 'signame'
+        """Stores 'data'-array of a given Signal or TimeBase named 'signame'
         to the target shotfile
         """
 
@@ -234,7 +234,7 @@ class WW:
                     result = libddww.wwsignal_( \
                              _error, self._diaref, name, _type, _lbuf, buffer, \
                              _stride, lname, lsbuf)
-                elif otype == Signalgroup:
+                elif otype == SignalGroup:
                     result = libddww.wwinsert_( \
                              _error, self._diaref, name, _type, _lbuf, buffer, \
                              _stride, _indices, lname, lsbuf)
@@ -247,12 +247,12 @@ class WW:
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
                              _stride, lname)
-                elif otype == Timebase:
+                elif otype == TimeBase:
                     result = libddww.wwtbase_( \
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
                              _stride, lname)
-                elif otype == Signalgroup:
+                elif otype == SignalGroup:
                     result = libddww.wwinsert_( \
                              _error, self._diaref, name, _type, _lbuf, \
                              data.ctypes.data_as(ct.POINTER(ctyp)), \
